# OpenDRIVE dataset of the inner ring road in Brunswick
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4043193.svg)](https://doi.org/10.5281/zenodo.4043193) [![License: CC BY 4.0](https://img.shields.io/badge/License-CC%20BY%204.0-lightgrey.svg)](https://creativecommons.org/licenses/by/4.0/)

This OpenDRIVE dataset contains a highly detailed model of the inner-city ring road of Brunswick, primarily to be used in driving simulation applications. The raw data has been surveyed by [3D Mapping Solutions GmbH](https://www.3d-mapping.de/) in 2012 with the transformation/annotation into OpenDRIVE having been finalised 2015-03-25. The dataset is maintained by the German Aero Space Center (DLR), [Institute of Transportation Systems](www.dlr.de/ts/en). It has been acquired in the context of the project [Application Platform for Intelligent Mobility (AIM)](https://www.dlr.de/ts/en/desktopdefault.aspx/tabid-6422/#gallery/25304) and funded by the [European Regional Development Fund (ERDF)](https://ec.europa.eu/regional_policy/de/funding/erdf/).

## Overview

![Surveyed road data](bs-inner-ring-road.png?raw=true "Surveyed road data")

## Key dataset features

- The model is optimised for the use in [Virtual Test Drive](https://www.mscsoftware.com/de/virtual-test-drive) and thus contains application-specific object and style definitions.
- Initial modeling in OpenDRIVE [v1.3](http://opendrive.org/download.html) with road `<planView>` geometries of type `<arc>` and `<line>`, later update to OpenDRIVE v1.4 by introduction of a `<geoReference>` header.
- Detailed lane modeling through `<width>` elements including driving, parking, shoulder, curbstone, pedestrian and bicycle lanes of which the latter are merely modeled for visual use cases (3-D virtual environment) and do not necessarily define a consistent, logical lane model, especially not in complex intersections.
- Exclusion of infrastrutural elements such as signals and signs.
- The absolute coordinate error of the `xy` component is expected to be less than 5 cm for road elements within the drivable surface (e.g. driving lane boundaries, road marks). Possibly greater absolute positioning error for other elements with increasing distance from the road reference line.

## Spatial coordinate reference

The dataset is referenced in a custom projection based on [WGS 84 / UTM zone 32N](http://epsg.io/32632) with a false easting of `-104763` and a false northing of `-5792795` in order to avoid floating point inaccuracies in primitive visualisation applications. The corresponding PROJ.4 projection definition is

```
+proj=tmerc +lat_0=0 +lon_0=9 +k=0.9996 +x_0=-104763 +y_0=-5792795 +datum=WGS84 +units=m +no_defs
```

Thus, in order to transform the geometries "back to UTM 32N" the following coordinate offsets have to be applied:

- `x += 604763.0`
- `y += 5792795.0`

Elevation information is defined as height above the WGS 84 ellipsoid.

## Citation

If you use this dataset, please cite the specific version using its DOI and the metadata provided in the
[CITATION file](CITATION.cff). For more information on the format, please see [Citation File Format (CFF)](https://citation-file-format.github.io/).

## Licence

This HD road network dataset is licenced under the terms of [Creative Commons Attribution 4.0 International](LICENSE.txt). It was surveyed in 2012 and has not been updated since. It is a prototypic, simplified modeling of urban road elements and is intended to be used in research and development only. Neither the completeness nor the correctness of the dataset can be guaranteed in any way. The dataset author does not take legal responsibility for the use of this dataset.